@@ -19,9 +19,6 @@ const MAX_RETRIES = 3;
 
 const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z.-]+):?(\d+)?\/(?:%23)?([\w.+-]+)/i;
 
-const AUTOSTART_DIR = `${GLib.get_user_config_dir()}${'/'}autostart`;
-const AUTOSTART_FILE = '/org.gnome.Polari.Autostart.desktop';
-
 var Application = GObject.registerClass({
     Signals: { 'prepare-shutdown': {},
                'room-focus-changed': {} },
@@ -271,10 +268,6 @@ var Application = GObject.registerClass({
         let action = this._settings.create_action('run-in-background');
         this.add_action(action);
 
-        this._settings.connect('changed::run-in-background',
-                               this._onRunInBackgroundChanged.bind(this));
-        this._onRunInBackgroundChanged();
-
         for (let i = 1; i < 10; i++)
             this.set_accels_for_action(`app.nth-room(${i})`, [`<Alt>${i}`]);
 
@@ -341,16 +334,18 @@ var Application = GObject.registerClass({
         this.activate_action('start-client', null);
 
         if (!this.active_window) {
+            if (this._windowRemovedId)
+                this.disconnect(this._windowRemovedId);
+            this._windowRemovedId = 0;
+
             if (this._needsInitialSetup()) {
                 new InitialSetupWindow({ application: this });
                 this._windowRemovedId = this.connect('window-removed', () => {
-                    this.disconnect(this._windowRemovedId);
-                    this._windowRemovedId = 0;
                     this.activate();
                 });
             } else {
                 let window = new MainWindow({ application: this });
-                window.connect('destroy', () => {
+                this._windowRemovedId = this.connect('window-removed', () => {
                     if (this._settings.get_boolean('run-in-background'))
                         return;
                     this.emit('prepare-shutdown');
@@ -752,37 +747,6 @@ var Application = GObject.registerClass({
         dialog.show();
     }
 
-    _createLink(file, target) {
-        try {
-            file.get_parent().make_directory_with_parents(null);
-        } catch (e) {
-            if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
-                throw e;
-            // not an error, carry on
-        }
-
-        file.make_symbolic_link(target, null);
-    }
-
-    _onRunInBackgroundChanged() {
-        let file = Gio.File.new_for_path(`${AUTOSTART_DIR}${AUTOSTART_FILE}`);
-
-        if (this._settings.get_boolean('run-in-background'))
-            try {
-                this._createLink(file, `${pkg.pkgdatadir}${AUTOSTART_FILE}`);
-            } catch (e) {
-                if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
-                    log(`Failed to create autostart link: ${e.message}`);
-            }
-        else
-            try {
-                file.delete(null);
-            } catch (e) {
-                if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND))
-                    log(`Failed to remove autostart link: ${e.message}`);
-            }
-    }
-
     _onStartClient() {
         if (this._telepathyClient)
             return;
@@ -826,7 +790,8 @@ var Application = GObject.registerClass({
             artists: [
                 'Sam Hewitt <hewittsamuel@gmail.com>',
                 'Jakub Steiner <jimmac@gmail.com>',
-                'Lapo Calamandrei <calamandrei@gmail.com>'
+                'Lapo Calamandrei <calamandrei@gmail.com>',
+                'Tobias Bernard <tbernard@gnome.org>'
             ],
             translator_credits: _("translator-credits"),
             comments: _("An Internet Relay Chat Client for GNOME"),
