@@ -87,8 +87,7 @@ var MainWindow = GObject.registerClass({
                        'userListPopover',
                        'roomListRevealer',
                        'overlay',
-                       'roomStack',
-                       'closeConfirmationDialog'],
+                       'roomStack'],
     Properties: {
         subtitle: GObject.ParamSpec.string('subtitle',
                                            'subtitle',
@@ -160,10 +159,12 @@ var MainWindow = GObject.registerClass({
         this._onAccountsChanged(this._accountsMonitor);
 
         this._roomManager = RoomManager.getDefault();
-        this._roomManager.connect('rooms-loaded',
-                                  this._onRoomsLoaded.bind(this));
-        this._roomManager.connect('room-removed',
-                                  this._onRoomRemoved.bind(this));
+        this._roomsLoadedId =
+            this._roomManager.connect('rooms-loaded',
+                                      this._onRoomsLoaded.bind(this));
+        this._roomRemovedId =
+            this._roomManager.connect('room-removed',
+                                      this._onRoomRemoved.bind(this));
         this._onRoomsLoaded();
 
         this._updateUserListLabel();
@@ -182,19 +183,9 @@ var MainWindow = GObject.registerClass({
                                   this._updateDecorations.bind(this));
         this._updateDecorations();
 
-        this._closeConfirmationDialog.transient_for = this;
-        this._closeConfirmationDialog.connect('response', (w, r) => {
-            if (r == Gtk.ResponseType.DELETE_EVENT)
-                return;
-
-            this._settings.set_boolean('run-in-background', r == Gtk.ResponseType.ACCEPT);
-            this.destroy();
-        });
-
         this.connect('window-state-event', this._onWindowStateEvent.bind(this));
         this.connect('size-allocate', this._onSizeAllocate.bind(this));
         this.connect('destroy', this._onDestroy.bind(this));
-        this.connect('delete-event', this._onDeleteEvent.bind(this));
         this.connect('notify::active-room', () => {
             this._updateUserListLabel();
         });
@@ -211,6 +202,7 @@ var MainWindow = GObject.registerClass({
         return this._subtitle;
     }
 
+    // eslint-disable-next-line camelcase
     get subtitle_visible() {
         return this._subtitle.length > 0;
     }
@@ -245,35 +237,12 @@ var MainWindow = GObject.registerClass({
             this._settings.reset('last-selected-channel');
 
         this.active_room = null;
-    }
 
-    _touchFile(file) {
-        try {
-            file.get_parent().make_directory_with_parents(null);
-        } catch (e) {
-            if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
-                throw e;
-            // not an error, carry on
-        }
+        this._roomManager.disconnect(this._roomsLoadedId);
+        this._roomManager.disconnect(this._roomRemovedId);
 
-        let stream = file.create(0, null);
-        stream.close(null);
-    }
-
-    _onDeleteEvent() {
-        let f = Gio.File.new_for_path(
-            `${GLib.get_user_cache_dir()}/polari/close-confirmation-shown`
-        );
-        try {
-            this._touchFile(f);
-        } catch (e) {
-            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
-                return Gdk.EVENT_PROPAGATE; // the dialog has been shown
-            log(`Failed to mark confirmation dialog as shown: ${e.message}`);
-        }
-
-        this._closeConfirmationDialog.show();
-        return Gdk.EVENT_STOP;
+        this._overlay.remove(this.application.notificationQueue);
+        this._overlay.remove(this.application.commandOutputQueue);
     }
 
     _onAccountsChanged() {
@@ -281,6 +250,10 @@ var MainWindow = GObject.registerClass({
         this._roomListRevealer.reveal_child = hasAccounts;
     }
 
+    _filterFallbackAppMenu(layoutStr) {
+        return layoutStr.split(',').filter(s => s != 'menu').join(',');
+    }
+
     _updateDecorations() {
         let layoutLeft = null;
         let layoutRight = null;
@@ -289,18 +262,20 @@ var MainWindow = GObject.registerClass({
         if (layout) {
             let [buttonsLeft, buttonsRight] = layout.split(':');
 
-            layoutLeft = `${buttonsLeft}:`;
-            layoutRight = `:${buttonsRight}`;
+            layoutLeft = `${this._filterFallbackAppMenu(buttonsLeft)}:`;
+            layoutRight = `:${this._filterFallbackAppMenu(buttonsRight)}`;
         }
 
         this._titlebarLeft.set_decoration_layout(layoutLeft);
         this._titlebarRight.set_decoration_layout(layoutRight);
     }
 
+    // eslint-disable-next-line camelcase
     get active_room() {
         return this._room;
     }
 
+    // eslint-disable-next-line camelcase
     set active_room(room) {
         if (room == this._room)
             return;
